@@ -63,7 +63,7 @@ TransactionTypeSpec.__module__ = "pyteal.abi"
 
 
 class Transaction(BaseType):
-    def __init__(self, spec: TransactionTypeSpec = None) -> None:
+    def __init__(self, spec: TransactionTypeSpec | None = None) -> None:
         if spec is None:
             super().__init__(TransactionTypeSpec())
         else:
@@ -82,24 +82,24 @@ class Transaction(BaseType):
             case ComputedValue():
                 return self._set_with_computed_type(value)
             case BaseType():
-                return self.stored_value.store(self.stored_value.load())
+                return self._stored_value.store(self._stored_value.load())
             case int():
-                return self.stored_value.store(Int(value))
+                return self._stored_value.store(Int(value))
             case Expr():
-                return self.stored_value.store(value)
+                return self._stored_value.store(value)
             case _:
                 raise TealInputError(f"Cant store a {type(value)} in a Transaction")
 
     def index(self) -> Expr:
-        return self.stored_value.load()
+        return self._stored_value.load()
 
     def decode(
         self,
         encoded: Expr,
         *,
-        start_index: Expr = None,
-        end_index: Expr = None,
-        length: Expr = None,
+        start_index: Expr | None = None,
+        end_index: Expr | None = None,
+        length: Expr | None = None,
     ) -> Expr:
         raise TealInputError("A Transaction cannot be decoded")
 
