@@ -23,7 +23,7 @@ from pyteal.ast.bytes import Bytes
 from pyteal.ast.unaryexpr import Len
 from pyteal.ast.binaryexpr import ExtractUint16
 from pyteal.ast.naryexpr import Concat
-from pyteal.ast.scratchvar import ScratchVar
+from pyteal.ast.abstractvar import alloc_abstract_var
 
 from pyteal.ast.abi.type import TypeSpec, BaseType, ComputedValue
 from pyteal.ast.abi.bool import (
@@ -72,8 +72,8 @@ def _encode_tuple(values: Sequence[BaseType]) -> Expr:
 
     tail_offset = Uint16()
     tail_offset_accumulator = Uint16()
-    tail_holder = ScratchVar(TealType.bytes)
-    encoded_tail = ScratchVar(TealType.bytes)
+    tail_holder = alloc_abstract_var(TealType.bytes)
+    encoded_tail = alloc_abstract_var(TealType.bytes)
 
     firstDynamicTail = True
     for i, elem in enumerate(values):
@@ -302,14 +302,14 @@ class Tuple(BaseType):
         self,
         encoded: Expr,
         *,
-        start_index: Expr = None,
-        end_index: Expr = None,
-        length: Expr = None,
+        start_index: Expr | None = None,
+        end_index: Expr | None = None,
+        length: Expr | None = None,
     ) -> Expr:
         extracted = substring_for_decoding(
             encoded, start_index=start_index, end_index=end_index, length=length
         )
-        return self.stored_value.store(extracted)
+        return self._stored_value.store(extracted)
 
     @overload
     def set(self, *values: BaseType) -> Expr:
@@ -352,10 +352,10 @@ class Tuple(BaseType):
             )
         if not all(myTypes[i] == values[i].type_spec() for i in range(len(myTypes))):
             raise TealInputError("Input values do not match type")
-        return self.stored_value.store(_encode_tuple(values))
+        return self._stored_value.store(_encode_tuple(values))
 
     def encode(self) -> Expr:
-        return self.stored_value.load()
+        return self._stored_value.load()
 
     def length(self) -> Expr:
         """Get the number of values this tuple holds as an Expr."""
@@ -679,6 +679,13 @@ class NamedTuple(Tuple):
         if name == "_NamedTuple__ready" or not self.__ready:
             super().__setattr__(name, field)
             return
+        # NOTE this pass condition is for following scenario:
+        # NamedTuple is an argument, and inside subroutine, subroutine set internal ABI value with FrameStorage
+        # This used to violate `__setattr__` for not allowing any assignment to attributes
+        # Now this case is lifted such that we can shift the storage scheme.
+        if name == "_stored_value" and self.__ready:
+            super().__setattr__(name, field)
+            return
         raise TealInputError("cannot assign to NamedTuple attributes.")
 
 
