@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from typing import Tuple, List, TYPE_CHECKING
+from typing import TYPE_CHECKING
 
 from pyteal.types import TealType
 from pyteal.ir import TealBlock, TealSimpleBlock
@@ -16,7 +16,7 @@ class Expr(ABC):
 
         self.trace = traceback.format_stack()[0:-1]
 
-    def getDefinitionTrace(self) -> List[str]:
+    def getDefinitionTrace(self) -> list[str]:
         return self.trace
 
     @abstractmethod
@@ -35,7 +35,7 @@ class Expr(ABC):
         pass
 
     @abstractmethod
-    def __teal__(self, options: "CompileOptions") -> Tuple[TealBlock, TealSimpleBlock]:
+    def __teal__(self, options: "CompileOptions") -> tuple[TealBlock, TealSimpleBlock]:
         """Assemble TEAL IR for this component and its arguments."""
         pass
 
